@@ -21,6 +21,7 @@
 #define PGrnLikeStrategyNumber			6	/* operator ~~ (LIKE) */
 #define PGrnContainStrategyNumber		7	/* operator %% (@ in Groonga) */
 #define PGrnQueryStrategyNumber			8	/* operator @@ (Groonga query) */
+#define PGrnJSONContainStrategyNumber	9	/* operator @> */
 
 /* file and table names */
 #define PGrnLogBasename					"pgroonga.log"
@@ -29,6 +30,13 @@
 #define PGrnSourcesTableNameFormat		PGrnSourcesTableNamePrefix "%u"
 #define PGrnSourcesCtidColumnName		"ctid"
 #define PGrnSourcesCtidColumnNameLength	(sizeof(PGrnSourcesCtidColumnName) - 1)
+#define PGrnJSONPathsTableNamePrefix	"JSONPaths"
+#define PGrnJSONPathsTableNameFormat	PGrnJSONPathsTableNamePrefix "%u_%u"
+#define PGrnJSONValuesTableNamePrefix	"JSONValues"
+#define PGrnJSONValuesTableNameFormat	PGrnJSONValuesTableNamePrefix "%u_%u"
+#define PGrnJSONTypesTableNamePrefix	"JSONTypes"
+#define PGrnJSONTypesTableNameFormat	PGrnJSONTypesTableNamePrefix "%u_%u"
+#define PGrnJSONValueLexiconNameFormat	"JSONValueLexicon%s%u_%u"
 #define PGrnLexiconNameFormat			"Lexicon%u_%u"
 #define PGrnIndexColumnName				"index"
 
@@ -44,6 +52,7 @@ extern Datum PGDLLEXPORT pgroonga_contain_text_array(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_contain_varchar(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_contain_varchar_array(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_match(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_match_jsonb(PG_FUNCTION_ARGS);
 
 extern Datum PGDLLEXPORT pgroonga_insert(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_beginscan(PG_FUNCTION_ARGS);
